import { ActionCreator, AnyAction } from 'redux';
import { AppError } from '../lib/errors';
/**
 * Curried function that wraps a {@link ThunkAction} with two calls to the provided loadingAction
 * {@link ActionCreator} (called with "true" before the wrapped action is dispatched, and with "false" after)
 * @param loadingAction - An action creator to create the actions to be dispatched before and after the wrappedAction-
 * @param wrappedAction - The thunkAction to be wrapped
 * @example dispatch(withLoading(toggleLoading)(saveClaims))
 */
export declare const withLoadingHandler: (loadingAction: ActionCreator<AnyAction>) => (wrappedAction: import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>) => import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>;
declare type ErrorModifier = (error: AppError | Error) => AppError;
/**
 * Curried function that wraps a {@link ThunkAction} with the provided error handler to be dispatched on thrown error
 * @param errorHandler - An {@link ActionCreator} to be dispatched with the error if an error is thrown
 * @param errorModifier - An optional modifier for the error which is thrown, is Identity function by default
 * @param wrappedAction - The {@link ThunkAction} to be wrapped. If dispatching it throws an error, the errorhandler will be dispatched
 * @example dispatch(withErrorHandling(showErrorScreen)(saveClaims))
 * @dev The return value from this modifier can be passed to other modifiers, i.e. modifiers can be composed
 * e.g. dispatch(withLoading(toggleLoading)(withErrorHandling(showErrorScreen)(saveClaims)))
 */
export declare const withErrorHandler: (errorHandler: ActionCreator<import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>>, errorModifier?: ErrorModifier | undefined) => (wrappedAction: import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>, modifier?: ErrorModifier | undefined) => import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>;
export declare const withLoading: (wrappedAction: import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>) => import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>;
export declare const withErrorScreen: (wrappedAction: import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>, modifier?: ErrorModifier | undefined) => import("redux-thunk").ThunkAction<AnyAction | Promise<void | AnyAction>, import("../reducers").RootState, import("../backendMiddleware").BackendMiddleware, AnyAction>;
export {};
