import { InteractionType } from 'jolocom-lib/js/interactionTokens/types';
import { JSONWebToken, JWTEncodable } from 'jolocom-lib/js/interactionTokens/JSONWebToken';
import { BackendMiddleware } from '../../backendMiddleware';
import { InteractionChannel, InteractionSummary, SignedCredentialWithMetadata, CredentialVerificationSummary } from './types';
import { CredentialMetadataSummary } from '../storage/storage';
import { Flow } from './flow';
import { Identity } from 'jolocom-lib/js/identity/identity';
export declare class Interaction {
    private interactionMessages;
    id: string;
    ctx: BackendMiddleware;
    flow: Flow;
    channel: InteractionChannel;
    participants: {
        requester: Identity;
        responder?: Identity;
    };
    constructor(ctx: BackendMiddleware, channel: InteractionChannel, id: string, interactionType: InteractionType);
    getMessages(): JSONWebToken<JWTEncodable>[];
    private findMessageByType;
    createAuthenticationResponse(): Promise<JSONWebToken<JWTEncodable>>;
    createCredentialResponse(selectedCredentials: CredentialVerificationSummary[]): Promise<JSONWebToken<JWTEncodable>>;
    createCredentialOfferResponseToken(selectedOffering: SignedCredentialWithMetadata[]): Promise<JSONWebToken<JWTEncodable>>;
    processInteractionToken(token: JSONWebToken<JWTEncodable>): Promise<void>;
    getSummary(): InteractionSummary;
    getAttributesByType: (type: string[]) => Promise<{
        type: string[];
        results: {
            verification: string;
            values: string[];
            fieldName: string;
        }[];
    }>;
    getStoredCredentialById(id: string): Promise<import("jolocom-lib/js/credentials/signedCredential/signedCredential").SignedCredential[]>;
    getVerifiableCredential: (query?: object | undefined) => Promise<import("jolocom-lib/js/credentials/signedCredential/signedCredential").SignedCredential[]>;
    /**
     * @dev This will crash with a credential receive because it doesn't contain a callbackURL
     * @todo This should probably come from the transport / channel handler
     * @todo Can this use the HttpAgent exported from instead of fetch? http.ts?
     * @todo The return type is difficult to pin down. If we're making a post, we expect a Response obejct,
     *   which either holds a token that can be parsed, or not (i.e. with credential responses, the answer from
     *   the server only holds the status code right now)
     *   If we're linking, the return value is a promise, as per {@see http://reactnative.dev/docs/linking.html#openurl}
     */
    send(token: JSONWebToken<JWTEncodable>): Promise<void | JSONWebToken<JWTEncodable>>;
    storeCredential(toSave: SignedCredentialWithMetadata[]): Promise<(void | undefined)[]>;
    storeCredentialMetadata: (metadata: CredentialMetadataSummary) => Promise<import("../storage/entities").CacheEntity>;
    storeIssuerProfile: () => Promise<import("../storage/entities").CacheEntity>;
}
